@@ -1,5 +1,5 @@
-#' @importFrom utils getFromNamespace
-NULL
+#' @importFrom utils getFromNamespace tail
+"_PACKAGE"
 
 .onUnload = function (libpath) {
   library.dynam.unload("backports", libpath)
